| wwc_classify | R Documentation |
Maps standardized effect sizes to the three What Works Clearinghouse baseline-equivalence categories. Sign is ignored; classification uses the absolute value of the effect size.
wwc_classify(es)
es |
Numeric vector of standardized effect sizes (e.g. values returned
by |
A character vector the same length as es:
"satisfied" when |es| <= 0.05 (no adjustment needed),
"satisfied_with_adjustment" when 0.05 < |es| <= 0.25
(equivalence holds only if the covariate is adjusted for in the
impact model),
"not_satisfied" when |es| > 0.25.
NA inputs return NA.
What Works Clearinghouse (2022). Procedures Handbook (Version 5.0). U.S. Department of Education.
wwc_classify(c(0.03, 0.12, 0.80))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.